@@ -39,6 +39,8 @@ def topic_directories(path) -> (list, list):
                 remaning_file, temperature = os.path.split(remaning_file)
                 remaning_file, isograd = os.path.split(remaning_file)
                 if temperature.isdigit():
+                    isograd = isograd.lower()
+                    method = method.upper()
                     if directory_listing.get(t):
                         directory_listing[t][isograd] = {method: full_path_data}
                     else:
@@ -63,6 +65,8 @@ def topic_directories(path) -> (list, list):
                     else:
                         method_listing[method] = {temperature: full_path_data}
 
+    for k, v in temperature_listing:
+        temperature_listing[k] = list(set(v))
     return directory_listing, method_listing, temperature_listing
 
 
